@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _VISIBILITY_WINDOW_H_
-#define _VISIBILITY_WINDOW_H_
+#ifndef VISIBILITY_WINDOW_H
+#define VISIBILITY_WINDOW_H
 
 #include <FL/Fl_Window.H>
 #include <FL/Fl_Choice.H>
