@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _GFACE_H_
-#define _GFACE_H_
+#ifndef GFACE_H
+#define GFACE_H
 
 #include <list>
 #include <string>
@@ -37,7 +37,7 @@ protected:
   GRegion *r1, *r2;
   mean_plane meanPlane;
   std::vector<GEdge *> embedded_edges;
-  std::set<GVertex *> embedded_vertices;
+  std::set<GVertex *, GEntityLessThan> embedded_vertices;
 
   BoundaryLayerColumns _columns;
 
@@ -122,7 +122,7 @@ public:
   virtual std::vector<GEdge *> embeddedEdges() const { return embedded_edges; }
 
   // edges that are embedded in the face
-  virtual std::set<GVertex *> embeddedVertices() const
+  virtual std::set<GVertex *, GEntityLessThan> embeddedVertices() const
   {
     return embedded_vertices;
   }
@@ -246,19 +246,19 @@ public:
   int getNumElementTypes() const { return 3; }
 
   // get total/by-type number of elements in the mesh
-  size_type getNumMeshElements() const;
-  unsigned int getNumMeshElementsByType(const int familyType) const;
-  unsigned int getNumMeshParentElements();
+  std::size_t getNumMeshElements() const;
+  std::size_t getNumMeshElementsByType(const int familyType) const;
+  std::size_t getNumMeshParentElements();
   void getNumMeshElements(unsigned *const c) const;
 
   // get the start of the array of a type of element
   MElement *const *getStartElementType(int type) const;
 
   // get the element at the given index
-  MElement *getMeshElement(unsigned int index) const;
+  MElement *getMeshElement(std::size_t index) const;
   // get the element at the given index for a given familyType
   MElement *getMeshElementByType(const int familyType,
-                                 const unsigned int index) const;
+                                 const std::size_t index) const;
 
   // reset the mesh attributes to default values
   virtual void resetMeshAttributes();
@@ -363,7 +363,7 @@ public:
   std::vector<SVector3> storage3; // sizes and directions storage
   std::vector<double> storage4; // sizes and directions storage
 
-  virtual bool reorder(const int elementType, const std::vector<int> &ordering);
+  virtual bool reorder(const int elementType, const std::vector<std::size_t> &ordering);
 };
 
 #endif
