@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <sstream>
 #include <iomanip>
@@ -59,7 +59,10 @@ static void readMSHEntities(FILE *fp, GModel *gm)
       GVertex *v1 = 0, *v2 = 0;
       for(int j = 0; j < n; j++) {
         int tagv;
-        if(fscanf(fp, "%d", &tagv) != 1) return;
+        if(fscanf(fp, "%d", &tagv) != 1){
+          delete ge;
+          return;
+        }
         GVertex *v = gm->getVertexByTag(tagv);
         if(!v) Msg::Error("Unknown GVertex %d", tagv);
         if(j == 0) v1 = v;
@@ -79,7 +82,10 @@ static void readMSHEntities(FILE *fp, GModel *gm)
       std::vector<int> edges, signs;
       for(int j = 0; j < n; j++) {
         int tage;
-        if(fscanf(fp, "%d", &tage) != 1) return;
+        if(fscanf(fp, "%d", &tage) != 1){
+          delete df;
+          return;
+        }
         edges.push_back(std::abs(tage));
         int sign = tage > 0 ? 1 : -1;
         signs.push_back(sign);
@@ -99,7 +105,10 @@ static void readMSHEntities(FILE *fp, GModel *gm)
       std::vector<int> faces, signs;
       for(int j = 0; j < n; j++) {
         int tagf;
-        if(fscanf(fp, "%d", &tagf) != 1) return;
+        if(fscanf(fp, "%d", &tagf) != 1){
+          delete dr;
+          return;
+        }
         faces.push_back(std::abs(tagf));
         int sign = tagf > 0 ? 1 : -1;
         signs.push_back(sign);
@@ -558,7 +567,7 @@ static void writeMSHPhysicals(FILE *fp, GEntity *ge)
 void writeMSHEntities(FILE *fp, GModel *gm) // also used in MSH2
 {
   fprintf(fp, "$Entities\n");
-  fprintf(fp, "%lu %d %d %d\n", gm->getNumVertices(), gm->getNumEdges(),
+  fprintf(fp, "%lu %lu %lu %lu\n", gm->getNumVertices(), gm->getNumEdges(),
           gm->getNumFaces(), gm->getNumRegions());
   for(GModel::viter it = gm->firstVertex(); it != gm->lastVertex(); ++it) {
     fprintf(fp, "%d ", (*it)->tag());
@@ -589,10 +598,10 @@ void writeMSHEntities(FILE *fp, GModel *gm) // also used in MSH2
     std::vector<int> signs(ori.begin(), ori.end());
 
     if(tags.size() == signs.size()) {
-      for(unsigned int i = 0; i < tags.size(); i++)
+      for(std::size_t i = 0; i < tags.size(); i++)
         tags[i] *= (signs[i] > 0 ? 1 : -1);
     }
-    for(unsigned int i = 0; i < tags.size(); i++) fprintf(fp, "%d ", tags[i]);
+    for(std::size_t i = 0; i < tags.size(); i++) fprintf(fp, "%d ", tags[i]);
     writeMSHPhysicals(fp, *it);
     fprintf(fp, "\n");
   }
@@ -608,10 +617,10 @@ void writeMSHEntities(FILE *fp, GModel *gm) // also used in MSH2
         itf++)
       signs.push_back(*itf);
     if(tags.size() == signs.size()) {
-      for(unsigned int i = 0; i < tags.size(); i++)
+      for(std::size_t i = 0; i < tags.size(); i++)
         tags[i] *= (signs[i] > 0 ? 1 : -1);
     }
-    for(unsigned int i = 0; i < tags.size(); i++) fprintf(fp, "%d ", tags[i]);
+    for(std::size_t i = 0; i < tags.size(); i++) fprintf(fp, "%d ", tags[i]);
     writeMSHPhysicals(fp, *it);
     fprintf(fp, "\n");
   }
@@ -625,7 +634,7 @@ static int getNumElementsMSH(GEntity *ge, bool saveAll, int saveSinglePartition)
     if(saveSinglePartition <= 0)
       n = ge->getNumMeshElements();
     else
-      for(unsigned int i = 0; i < ge->getNumMeshElements(); i++)
+      for(std::size_t i = 0; i < ge->getNumMeshElements(); i++)
         if(ge->getMeshElement(i)->getPartition() == saveSinglePartition) n++;
   }
   return n;
@@ -642,10 +651,10 @@ static void writeElementMSH(FILE *fp, GModel *model, MElement *ele, bool binary,
     for(std::multimap<MElement *, short>::iterator it = itp.first;
         it != itp.second; it++)
       ghosts.push_back(it->second);
-    ele->writeMSH(fp, binary, elementary, &ghosts);
+    ele->writeMSH3(fp, binary, elementary, &ghosts);
   }
   else
-    ele->writeMSH(fp, binary, elementary);
+    ele->writeMSH3(fp, binary, elementary);
 }
 
 template <class T>
@@ -654,7 +663,7 @@ static void writeElementsMSH(FILE *fp, GModel *model, GEntity *ge,
                              int saveSinglePartition, bool binary)
 {
   if(saveAll || ge->physicals.size()) {
-    for(unsigned int i = 0; i < ele.size(); i++) {
+    for(std::size_t i = 0; i < ele.size(); i++) {
       if(saveSinglePartition && ele[i]->getPartition() != saveSinglePartition)
         continue;
       writeElementMSH(fp, model, ele[i], binary, ge->tag());
@@ -666,12 +675,12 @@ void writeMSHPeriodicNodes(FILE *fp, std::vector<GEntity *> &entities,
                            bool renumber) // also used in MSH2
 {
   int count = 0;
-  for(unsigned int i = 0; i < entities.size(); i++)
+  for(std::size_t i = 0; i < entities.size(); i++)
     if(entities[i]->getMeshMaster() != entities[i]) count++;
   if(!count) return;
   fprintf(fp, "$Periodic\n");
   fprintf(fp, "%d\n", count);
-  for(unsigned int i = 0; i < entities.size(); i++) {
+  for(std::size_t i = 0; i < entities.size(); i++) {
     GEntity *g_slave = entities[i];
     GEntity *g_master = g_slave->getMeshMaster();
     if(g_slave != g_master) {
@@ -692,9 +701,9 @@ void writeMSHPeriodicNodes(FILE *fp, std::vector<GEntity *> &entities,
         MVertex *v1 = it->first;
         MVertex *v2 = it->second;
         if(renumber)
-          fprintf(fp, "%d %d\n", v1->getIndex(), v2->getIndex());
+          fprintf(fp, "%ld %ld\n", v1->getIndex(), v2->getIndex());
         else
-          fprintf(fp, "%d %d\n", v1->getNum(), v2->getNum());
+          fprintf(fp, "%lu %lu\n", v1->getNum(), v2->getNum());
       }
     }
   }
@@ -736,7 +745,7 @@ int GModel::_writeMSH3(const std::string &name, double version, bool binary,
   std::vector<GEntity *> entities;
   getEntities(entities);
   int numElements = 0;
-  for(unsigned int i = 0; i < entities.size(); i++)
+  for(std::size_t i = 0; i < entities.size(); i++)
     numElements += getNumElementsMSH(entities[i], saveAll, saveSinglePartition);
 
   fprintf(fp, "$MeshFormat\n");
@@ -764,8 +773,8 @@ int GModel::_writeMSH3(const std::string &name, double version, bool binary,
 
   fprintf(fp, "$Nodes\n");
   fprintf(fp, "%d\n", numVertices);
-  for(unsigned int i = 0; i < entities.size(); i++)
-    for(unsigned int j = 0; j < entities[i]->mesh_vertices.size(); j++)
+  for(std::size_t i = 0; i < entities.size(); i++)
+    for(std::size_t j = 0; j < entities[i]->mesh_vertices.size(); j++)
       entities[i]->mesh_vertices[j]->writeMSH(fp, binary, saveParametric,
                                               scalingFactor);
 
@@ -826,7 +835,7 @@ int GModel::_writePartitionedMSH3(const std::string &baseName, double version,
     return 0;
   }
 
-  for(unsigned int partition = 0; partition < getNumPartitions(); partition++) {
+  for(std::size_t partition = 0; partition < getNumPartitions(); partition++) {
     std::ostringstream sstream;
     sstream << baseName << "_" << std::setw(6) << std::setfill('0')
             << partition;
