@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _GMODELIO_OCC_H_
-#define _GMODELIO_OCC_H_
+#ifndef GMODELIO_OCC_H
+#define GMODELIO_OCC_H
 
 #include <vector>
 #include <map>
@@ -32,7 +32,7 @@ class BRepSweep_Prism;
 class BRepSweep_Revol;
 class BRepBuilderAPI_Transform;
 class BRepBuilderAPI_GTransform;
-class OCCMeshAttributesRTree;
+class OCCAttributesRTree;
 
 class OCC_Internals {
 public:
@@ -67,7 +67,7 @@ private:
   std::set<std::pair<int, int> > _toPreserve;
 
   // mesh attributes
-  OCCMeshAttributesRTree *_meshAttributes;
+  OCCAttributesRTree *_attributes;
 
   // get tag of shape, but search for other candidates at the same location if
   // the actual shape is not found
@@ -143,14 +143,14 @@ private:
                bool removeVolume);
 
   // set extruded mesh attributes
-  void _setExtrudedMeshAttributes(const TopoDS_Compound &c, BRepSweep_Prism *p,
-                                  BRepSweep_Revol *r, ExtrudeParams *e,
-                                  double x, double y, double z, double dx,
-                                  double dy, double dz, double ax, double ay,
-                                  double az, double angle);
-  void _copyExtrudedMeshAttributes(TopoDS_Edge edge, GEdge *ge);
-  void _copyExtrudedMeshAttributes(TopoDS_Face face, GFace *gf);
-  void _copyExtrudedMeshAttributes(TopoDS_Solid solid, GRegion *gr);
+  void _setExtrudedAttributes(const TopoDS_Compound &c, BRepSweep_Prism *p,
+                              BRepSweep_Revol *r, ExtrudeParams *e,
+                              double x, double y, double z, double dx,
+                              double dy, double dz, double ax, double ay,
+                              double az, double angle);
+  void _copyExtrudedAttributes(TopoDS_Edge edge, GEdge *ge);
+  void _copyExtrudedAttributes(TopoDS_Face face, GFace *gf);
+  void _copyExtrudedAttributes(TopoDS_Solid solid, GRegion *gr);
 
 public:
   OCC_Internals();
@@ -309,6 +309,8 @@ public:
               double y, double z, double a, double b, double c);
   bool symmetry(const std::vector<std::pair<int, int> > &inDimTags, double a,
                 double b, double c, double d);
+  bool affine(const std::vector<std::pair<int, int> > &inDimTags,
+              const std::vector<double> &mat);
 
   // copy and remove
   bool copy(const std::vector<std::pair<int, int> > &inDimTags,
@@ -344,12 +346,12 @@ public:
   GRegion *getRegionForOCCShape(GModel *model, const TopoDS_Solid &toFind);
 
   // STL utilities
-  bool makeFaceSTL(TopoDS_Face s, std::vector<SPoint2> &vertices_uv,
+  bool makeFaceSTL(const TopoDS_Face &s, std::vector<SPoint2> &vertices_uv,
                    std::vector<int> &triangles);
-  bool makeFaceSTL(TopoDS_Face s, std::vector<SPoint2> &vertices_uv,
+  bool makeFaceSTL(const TopoDS_Face &s, std::vector<SPoint2> &vertices_uv,
                    std::vector<SPoint3> &vertices,
                    std::vector<SVector3> &normals, std::vector<int> &triangles);
-  bool makeFaceSTL(TopoDS_Face s, std::vector<SPoint3> &vertices,
+  bool makeFaceSTL(const TopoDS_Face &s, std::vector<SPoint3> &vertices,
                    std::vector<SVector3> &normals, std::vector<int> &triangles);
   bool makeSolidSTL(const TopoDS_Solid &s, std::vector<SPoint3> &vertices,
                     std::vector<SVector3> &normals,
@@ -637,6 +639,11 @@ public:
   {
     return _error("apply symmetry");
   }
+  bool affine(const std::vector<std::pair<int, int> > &inDimTags,
+              const std::vector<double> &mat)
+  {
+    return _error("apply affine transform");
+  }
   bool copy(const std::vector<std::pair<int, int> > &inDimTags,
             std::vector<std::pair<int, int> > &outDimTags)
   {
