@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _MLINE_H_
-#define _MLINE_H_
+#ifndef MLINE_H
+#define MLINE_H
 
 #include "MElement.h"
 #include "nodalBasis.h"
@@ -199,14 +199,14 @@ public:
          int num = 0, int part = 0)
     : MLine(v0, v1, num, part), _vs(vs)
   {
-    for(unsigned int i = 0; i < _vs.size(); i++)
+    for(std::size_t i = 0; i < _vs.size(); i++)
       _vs[i]->setPolynomialOrder(_vs.size() + 1);
   }
   MLineN(const std::vector<MVertex *> &v, int num = 0, int part = 0)
     : MLine(v[0], v[1], num, part)
   {
-    for(unsigned int i = 2; i < v.size(); i++) _vs.push_back(v[i]);
-    for(unsigned int i = 0; i < _vs.size(); i++)
+    for(std::size_t i = 2; i < v.size(); i++) _vs.push_back(v[i]);
+    for(std::size_t i = 0; i < _vs.size(); i++)
       _vs[i]->setPolynomialOrder(_vs.size() + 1);
   }
   ~MLineN() {}
@@ -235,22 +235,25 @@ public:
   {
     v.resize(2 + _vs.size());
     MLine::_getEdgeVertices(v);
-    for(unsigned int i = 0; i != _vs.size(); ++i) v[i + 2] = _vs[i];
+    for(std::size_t i = 0; i != _vs.size(); ++i) v[i + 2] = _vs[i];
   }
   virtual int getTypeForMSH() const
   {
-    if(_vs.size() == 0) return MSH_LIN_2;
-    if(_vs.size() == 1) return MSH_LIN_3;
-    if(_vs.size() == 2) return MSH_LIN_4;
-    if(_vs.size() == 3) return MSH_LIN_5;
-    if(_vs.size() == 4) return MSH_LIN_6;
-    if(_vs.size() == 5) return MSH_LIN_7;
-    if(_vs.size() == 6) return MSH_LIN_8;
-    if(_vs.size() == 7) return MSH_LIN_9;
-    if(_vs.size() == 8) return MSH_LIN_10;
-    if(_vs.size() == 9) return MSH_LIN_11;
-    Msg::Error("no tag matches a line with %d vertices", 8 + _vs.size());
-    return 0;
+    switch(_vs.size()){
+    case 0: return MSH_LIN_2;
+    case 1: return MSH_LIN_3;
+    case 2: return MSH_LIN_4;
+    case 3: return MSH_LIN_5;
+    case 4: return MSH_LIN_6;
+    case 5: return MSH_LIN_7;
+    case 6: return MSH_LIN_8;
+    case 7: return MSH_LIN_9;
+    case 8: return MSH_LIN_10;
+    case 9: return MSH_LIN_11;
+    default:
+      Msg::Error("no tag matches a line with %d vertices", 8 + _vs.size());
+      return 0;
+    }
   }
   virtual void reverse()
   {
