@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <limits>
 #include "GmshConfig.h"
@@ -346,7 +346,7 @@ void OCCEdge::writeGEO(FILE *fp)
       center = Handle(Geom_Circle)::DownCast(curve)->Location();
     }
     // GEO supports only circle arcs < Pi
-    if(s1 - s0 < M_PI) {
+    if(s1 - s0 < M_PI && getBeginVertex() && getEndVertex()) {
       fprintf(fp, "p%d = newp;\n", tag());
       fprintf(fp, "Point(p%d + 1) = {%.16g, %.16g, %.16g};\n", tag(),
               center.X(), center.Y(), center.Z());
