@@ -23,6 +23,7 @@ discreteEdge::discreteEdge(GModel *model, int num, GVertex *_v0, GVertex *_v1)
   Curve *c = CreateCurve(num, MSH_SEGM_DISCRETE, 0, 0, 0, -1, -1, 0., 1.);
   Tree_Add(model->getGEOInternals()->Curves, &c);
   CreateReversedCurve(c);
+  _split[0] = _split[1] = NULL;
 }
 
 discreteEdge::discreteEdge(GModel *model, int num) : GEdge(model, num)
@@ -30,43 +31,47 @@ discreteEdge::discreteEdge(GModel *model, int num) : GEdge(model, num)
   Curve *c = CreateCurve(num, MSH_SEGM_DISCRETE, 0, 0, 0, -1, -1, 0., 1.);
   Tree_Add(model->getGEOInternals()->Curves, &c);
   CreateReversedCurve(c);
+  _split[0] = _split[1] = NULL;
 }
 
 discreteEdge::~discreteEdge()
 {
-  for(unsigned int i = 0; i < discrete_lines.size(); i++)
+  for(std::size_t i = 0; i < discrete_lines.size(); i++)
     delete discrete_lines[i];
-  for(unsigned int i = 0; i < discrete_vertices.size(); i++)
+  for(std::size_t i = 0; i < discrete_vertices.size(); i++)
     delete discrete_vertices[i];
   discrete_lines.clear();
   discrete_vertices.clear();
+  _split[0] = _split[1] = NULL;
 }
 
 void discreteEdge::orderMLines()
 {
   size_t ss = lines.size();
+  if(!ss) return;
+
   std::vector<MEdge> ed;
   std::vector<std::vector<MVertex *> > vs;
-  for(unsigned int i = 0; i < lines.size(); i++) {
+  for(std::size_t i = 0; i < lines.size(); i++) {
     ed.push_back(MEdge(lines[i]->getVertex(0), lines[i]->getVertex(1)));
     delete lines[i];
   }
   lines.clear();
 
   if(!SortEdgeConsecutive(ed, vs))
-    Msg::Warning("Discrete edge segments cannot be ordered");
+    Msg::Warning("Discrete curve elements cannot be ordered");
 
   if(vs.size() != 1)
-    Msg::Warning("Discrete Edge %d is mutiply connected", tag());
+    Msg::Warning("Discrete curve %d is mutiply connected", tag());
 
-  unsigned int START = 0;
+  std::size_t START = 0;
   for(; START < vs[0].size(); START++)
     if(vs[0][START]->onWhat()->dim() == 0) break;
 
   if(START == vs[0].size())
-    Msg::Warning("Discrete Edge %d topology is wrong", tag());
+    Msg::Warning("Discrete curve %d topology is wrong", tag());
 
-  unsigned int i = START;
+  std::size_t i = START;
   while(lines.size() != ss) {
     if(vs[0][i % vs[0].size()] != vs[0][(i + 1) % vs[0].size()])
       lines.push_back(
@@ -75,17 +80,20 @@ void discreteEdge::orderMLines()
   }
 
   mesh_vertices.clear();
-  for(unsigned int i = 0; i < lines.size() - 1; ++i) {
+  for(std::size_t i = 0; i < lines.size() - 1; ++i) {
     MVertex *v11 = lines[i]->getVertex(1);
     mesh_vertices.push_back(v11);
   }
-  GVertex *g0 = static_cast<GVertex *>(lines[0]->getVertex(0)->onWhat());
-  if(!g0) Msg::Error("Compound Edge with non consecutive lines");
-  GVertex *g1 =
-    static_cast<GVertex *>(lines[lines.size() - 1]->getVertex(1)->onWhat());
-  if(!g1) Msg::Error("Compound Edge with non consecutive lines");
-  setBeginVertex(g0);
-  setEndVertex(g1);
+  if(lines.empty()){
+    Msg::Error("No line elements in discrete curve %d", tag());
+    return;
+  }
+  GVertex *g0 = dynamic_cast<GVertex *>(lines[0]->getVertex(0)->onWhat());
+  if(g0) setBeginVertex(g0);
+  GVertex *g1 = dynamic_cast<GVertex *>(lines[lines.size() - 1]->getVertex(1)->onWhat());
+  if(g1) setEndVertex(g1);
+  if(!g0 || !g1)
+    Msg::Error("Discrete curve %d has non consecutive line elements", tag());
 }
 
 bool discreteEdge::getLocalParameter(const double &t, int &iLine,
@@ -144,7 +152,7 @@ SVector3 discreteEdge::firstDer(double par) const
 
 double discreteEdge::curvature(double par) const
 {
-  Msg::Error("Curvature for discrete edge not implemented yet");
+  Msg::Error("Curvature for discrete curve not implemented yet");
   return 0.;
 }
 
@@ -155,15 +163,19 @@ Range<double> discreteEdge::parBounds(int i) const
 
 void discreteEdge::createGeometry()
 {
+  if(lines.empty()) return;
+
   if(discrete_lines.empty()) {
     orderMLines();
 
-    bool reverse = lines[0]->getVertex(0) == getEndVertex()->mesh_vertices[0];
+    bool reverse = false;
+    if(getEndVertex())
+      reverse = (lines[0]->getVertex(0) == getEndVertex()->mesh_vertices[0]);
 
     std::map<MVertex *, MVertex *> old2new;
 
-    for(unsigned int i = 0; i < lines.size(); i++) {
-      for(unsigned int j = 0; j < 2; j++) {
+    for(std::size_t i = 0; i < lines.size(); i++) {
+      for(std::size_t j = 0; j < 2; j++) {
         MVertex *v = lines[i]->getVertex(j);
         if(old2new.find(v) == old2new.end()) {
           MVertex *vnew = new MVertex(v->x(), v->y(), v->z(), this);
@@ -174,7 +186,7 @@ void discreteEdge::createGeometry()
 
     std::vector<MLine *> _temp;
     discrete_lines.resize(lines.size());
-    for(unsigned int i = 0; i < lines.size(); i++) {
+    for(std::size_t i = 0; i < lines.size(); i++) {
       MVertex *v0 = lines[i]->getVertex(0);
       MVertex *v1 = lines[i]->getVertex(1);
       MVertex *v00 = old2new[v0];
@@ -186,7 +198,7 @@ void discreteEdge::createGeometry()
     }
     // compute parameters and recompute the vertices
     _pars.push_back(0.0);
-    for(unsigned int i = 1; i < discrete_lines.size(); i++) {
+    for(std::size_t i = 1; i < discrete_lines.size(); i++) {
       _pars.push_back((double)i);
       MVertex *newv = discrete_lines[i]->getVertex(0);
       discrete_vertices.push_back(newv);
@@ -205,10 +217,3 @@ void discreteEdge::mesh(bool verbose)
   mesher(this);
 #endif
 }
-
-void discreteEdge::writeGEO(FILE *fp)
-{
-  if(getBeginVertex() && getEndVertex())
-    fprintf(fp, "Discrete Line(%d) = {%d,%d};\n", tag(),
-            getBeginVertex()->tag(), getEndVertex()->tag());
-}
