@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _GMSH_FACE_H_
-#define _GMSH_FACE_H_
+#ifndef GMSH_FACE_H
+#define GMSH_FACE_H
 
 #include "GFace.h"
 
