@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _PARTITION_EDGE_H_
-#define _PARTITION_EDGE_H_
+#ifndef PARTITION_EDGE_H
+#define PARTITION_EDGE_H
 
 #include "GModel.h"
 #include "discreteEdge.h"
