@@ -278,7 +278,7 @@ static bool getEdgeVerticesOnGeo(GEdge *ge, MVertex *v0, MVertex *v1,
     if(failed) {
       Msg::Warning(
         "Failed to compute equidistant parameters (relax = %g, value = %g) "
-        "for edge %d-%d parametrized with %g %g on GEdge %d",
+        "for edge %d-%d parametrized with %g %g on curve %d",
         relax, US[1], v0->getNum(), v1->getNum(), u0, u1, ge->tag());
       US[0] = uMin;
       const double du = (uMax - uMin) / (nPts + 1);
@@ -355,7 +355,8 @@ static bool getEdgeVerticesOnGeo(GFace *gf, MVertex *v0, MVertex *v1,
     }
   }
   else {
-    Msg::Error("Cannot reparam a mesh Vertex in high order meshing");
+    Msg::Error("Cannot reparametrize mesh edge %lu-%lu on surface %d",
+               v0->getNum(), v1->getNum(), gf->tag());
     return false;
   }
 
@@ -1246,6 +1247,10 @@ static void updatePeriodicEdgesAndFaces(GModel *m)
 
   for(GModel::eiter it = m->firstEdge(); it != m->lastEdge(); ++it) {
     GEdge *tgt = *it;
+
+    // non complete periodic info (e.g. through extrusion)
+    if(tgt->vertexCounterparts.empty()) continue;
+
     GEdge *src = dynamic_cast<GEdge *>(tgt->getMeshMaster());
 
     if(src != NULL && src != tgt) {
@@ -1253,15 +1258,14 @@ static void updatePeriodicEdgesAndFaces(GModel *m)
       std::map<MVertex *, MVertex *> &p2p = tgt->correspondingHOPoints;
       p2p.clear();
 
-      Msg::Info(
-        "Constructing high order periodicity for edge connection %d - %d",
-        tgt->tag(), src->tag());
+      Msg::Info("Reconstructing periodicity for curve connection %d - %d",
+                tgt->tag(), src->tag());
 
       std::map<MEdge, MLine *, Less_Edge> srcEdges;
       for(std::size_t i = 0; i < src->getNumMeshElements(); i++) {
         MLine *srcLine = dynamic_cast<MLine *>(src->getMeshElement(i));
         if(!srcLine) {
-          Msg::Error("Master element %d is not an edge",
+          Msg::Error("Master element %d is not a line",
                      src->getMeshElement(i)->getNum());
           return;
         }
@@ -1272,7 +1276,7 @@ static void updatePeriodicEdgesAndFaces(GModel *m)
         MLine *tgtLine = dynamic_cast<MLine *>(tgt->getMeshElement(i));
         MVertex *vtcs[2];
         if(!tgtLine) {
-          Msg::Error("Slave element %d is not an edge",
+          Msg::Error("Slave element %d is not a line",
                      tgt->getMeshElement(i)->getNum());
           return;
         }
@@ -1280,9 +1284,9 @@ static void updatePeriodicEdgesAndFaces(GModel *m)
           MVertex *vtx = tgtLine->getVertex(iVtx);
           std::map<MVertex *, MVertex *>::iterator tIter = v2v.find(vtx);
           if(tIter == v2v.end()) {
-            Msg::Error("Cannot find periodic counterpart of vertex %d"
-                       " of edge %d on edge %d",
-                       vtx->getNum(), tgt->tag(), src->tag());
+            Msg::Error("Cannot find periodic counterpart of node %d"
+                       " of curve %d on curve %d", vtx->getNum(), tgt->tag(),
+                       src->tag());
             return;
           }
           else
@@ -1292,8 +1296,8 @@ static void updatePeriodicEdgesAndFaces(GModel *m)
         std::map<MEdge, MLine *, Less_Edge>::iterator srcIter =
           srcEdges.find(MEdge(vtcs[0], vtcs[1]));
         if(srcIter == srcEdges.end()) {
-          Msg::Error("Can't find periodic counterpart of edge %d-%d on edge %d"
-                     ", connected to edge %d-%d on %d",
+          Msg::Error("Can't find periodic counterpart of mesh edge %d-%d "
+                     "on curve %d, connected to mesh edge %d-%d on curve %d",
                      tgtLine->getVertex(0)->getNum(),
                      tgtLine->getVertex(1)->getNum(), tgt->tag(),
                      vtcs[0]->getNum(), vtcs[1]->getNum(), src->tag());
@@ -1322,11 +1326,14 @@ static void updatePeriodicEdgesAndFaces(GModel *m)
 
   for(GModel::fiter it = m->firstFace(); it != m->lastFace(); ++it) {
     GFace *tgt = *it;
+
+    // non complete periodic info (e.g. through extrusion)
+    if(tgt->vertexCounterparts.empty()) continue;
+
     GFace *src = dynamic_cast<GFace *>(tgt->getMeshMaster());
     if(src != NULL && src != tgt) {
-      Msg::Info(
-        "Constructing high order periodicity for face connection %d - %d",
-        tgt->tag(), src->tag());
+      Msg::Info("Reconstructing periodicity for surface connection %d - %d",
+                tgt->tag(), src->tag());
 
       std::map<MVertex *, MVertex *> &v2v = tgt->correspondingVertices;
       std::map<MVertex *, MVertex *> &p2p = tgt->correspondingHOPoints;
@@ -1358,8 +1365,8 @@ static void updatePeriodicEdgesAndFaces(GModel *m)
 
           std::map<MVertex *, MVertex *>::iterator tIter = v2v.find(vtx);
           if(tIter == v2v.end()) {
-            Msg::Error("Cannot find periodic counterpart of vertex %d"
-                       " of surface %d on surface %d",
+            Msg::Error("Cannot find periodic counterpart of node %d "
+                       "of surface %d on surface %d",
                        vtx->getNum(), tgt->tag(), src->tag());
             return;
           }
@@ -1373,8 +1380,8 @@ static void updatePeriodicEdgesAndFaces(GModel *m)
           std::ostringstream faceDef;
           for(int iVtx = 0; iVtx < nbVtcs; iVtx++)
             faceDef << vtcs[iVtx]->getNum() << " ";
-          Msg::Error("Cannot find periodic counterpart of face %s in face %d "
-                     "connected to %d",
+          Msg::Error("Cannot find periodic counterpart of mesh face %s in "
+                     "surface %d on surface %d",
                      faceDef.str().c_str(), tgt->tag(), src->tag());
           return;
         }
@@ -1399,7 +1406,7 @@ static void updatePeriodicEdgesAndFaces(GModel *m)
 #endif
   }
 
-  Msg::Debug("Finalized high order topology of periodic connections");
+  Msg::Debug("Finalized topology of periodic connections");
 }
 
 void SetOrder1(GModel *m, bool onlyVisible)
