@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "GmshConfig.h"
 #include "GModel.h"
@@ -37,7 +37,7 @@ static double smoothPrimitive(GEdge *ge, double alpha,
 
     // use a gauss-seidel iteration; iterate forward and then backward;
     // convergence is usually very fast
-    for(unsigned int i = 1; i < Points.size(); i++) {
+    for(std::size_t i = 1; i < Points.size(); i++) {
       double dh =
         (Points[i].xp / Points[i].lc - Points[i - 1].xp / Points[i - 1].lc);
       double dt = Points[i].t - Points[i - 1].t;
@@ -80,15 +80,7 @@ static double smoothPrimitive(GEdge *ge, double alpha,
 struct F_LcB {
   double operator()(GEdge *ge, double t)
   {
-    /*  BoundaryLayerField *blf = 0;
-  #if defined(HAVE_ANN)
-    FieldManager *fields = ge->model()->getFields();
-    Field *bl_field = fields->get(fields->getBoundaryLayerField());
-    blf = dynamic_cast<BoundaryLayerField*> (bl_field);
-  #endif
-    */
     GPoint p = ge->point(t);
-
     return BGM_MeshSize(ge, t, 0, p.x(), p.y(), p.z());
   }
 };
@@ -96,31 +88,18 @@ struct F_LcB {
 struct F_Lc {
   double operator()(GEdge *ge, double t)
   {
-    /*
-    BoundaryLayerField *blf = 0;
-    #if defined(HAVE_ANN)
-    FieldManager *fields = ge->model()->getFields();
-    Field *bl_field = fields->get(fields->getBoundaryLayerField());
-    blf = dynamic_cast<BoundaryLayerField*> (bl_field);
-    #endif
-    */
     GPoint p = ge->point(t);
-
     Range<double> bounds = ge->parBounds(0);
     double t_begin = bounds.low();
     double t_end = bounds.high();
-
     double lc_here;
-
-    if(t == t_begin)
+    if(t == t_begin && ge->getBeginVertex())
       lc_here = BGM_MeshSize(ge->getBeginVertex(), t, 0, p.x(), p.y(), p.z());
-    else if(t == t_end)
+    else if(t == t_end && ge->getEndVertex())
       lc_here = BGM_MeshSize(ge->getEndVertex(), t, 0, p.x(), p.y(), p.z());
     else
       lc_here = BGM_MeshSize(ge, t, 0, p.x(), p.y(), p.z());
-
     SVector3 der = ge->firstDer(t);
-
     return norm(der) / lc_here;
   }
 };
@@ -135,18 +114,15 @@ struct F_Lc_aniso {
     double t_begin = bounds.low();
     double t_end = bounds.high();
 
-    if(t == t_begin)
+    if(t == t_begin && ge->getBeginVertex())
       lc_here = BGM_MeshMetric(ge->getBeginVertex(), t, 0, p.x(), p.y(), p.z());
-    else if(t == t_end)
+    else if(t == t_end && ge->getEndVertex())
       lc_here = BGM_MeshMetric(ge->getEndVertex(), t, 0, p.x(), p.y(), p.z());
     else
       lc_here = BGM_MeshMetric(ge, t, 0, p.x(), p.y(), p.z());
 
-#if defined(HAVE_ANN)
     FieldManager *fields = ge->model()->getFields();
-    int n = fields->getNumBoundaryLayerFields();
-
-    for(int i = 0; i < n; ++i) {
+    for(int i = 0; i < fields->getNumBoundaryLayerFields(); ++i) {
       Field *bl_field = fields->get(fields->getBoundaryLayerField(i));
       if(bl_field == NULL) continue;
       BoundaryLayerField *blf = dynamic_cast<BoundaryLayerField *>(bl_field);
@@ -155,7 +131,6 @@ struct F_Lc_aniso {
       blf->computeFor1dMesh(p.x(), p.y(), p.z(), lc_bgm);
       lc_here = intersection_conserveM1(lc_here, lc_bgm);
     }
-#endif
 
     SVector3 der = ge->firstDer(t);
     return std::sqrt(dot(der, lc_here, der));
@@ -300,6 +275,12 @@ static double Integration(GEdge *ge, double t1, double t2, function f,
 
 void copyMesh(GEdge *from, GEdge *to, int direction)
 {
+  if(!from->getBeginVertex() || !from->getEndVertex() ||
+     !to->getBeginVertex() || !to->getEndVertex()){
+    Msg::Error("Cannot copy mesh on curves without begin/end points");
+    return;
+  }
+
   Range<double> u_bounds = from->parBounds(0);
   double u_min = u_bounds.low();
   double u_max = u_bounds.high();
@@ -318,7 +299,7 @@ void copyMesh(GEdge *from, GEdge *to, int direction)
   to->correspondingVertices[vt0] = direction > 0 ? vs0 : vs1;
   to->correspondingVertices[vt1] = direction > 0 ? vs1 : vs0;
 
-  for(unsigned int i = 0; i < from->mesh_vertices.size(); i++) {
+  for(std::size_t i = 0; i < from->mesh_vertices.size(); i++) {
     int index = (direction < 0) ? (from->mesh_vertices.size() - 1 - i) : i;
     MVertex *v = from->mesh_vertices[index];
     double u;
@@ -330,7 +311,7 @@ void copyMesh(GEdge *from, GEdge *to, int direction)
     to->mesh_vertices.push_back(vv);
     to->correspondingVertices[vv] = v;
   }
-  for(unsigned int i = 0; i < to->mesh_vertices.size() + 1; i++) {
+  for(std::size_t i = 0; i < to->mesh_vertices.size() + 1; i++) {
     MVertex *v0 = (i == 0) ? to->getBeginVertex()->mesh_vertices[0] :
                              to->mesh_vertices[i - 1];
     MVertex *v1 = (i == to->mesh_vertices.size()) ?
@@ -342,8 +323,10 @@ void copyMesh(GEdge *from, GEdge *to, int direction)
 
 void deMeshGEdge::operator()(GEdge *ge)
 {
-  if(ge->geomType() == GEntity::DiscreteCurve && !CTX::instance()->meshDiscrete)
-    return;
+  if(ge->geomType() == GEntity::DiscreteCurve){
+    if(!static_cast<discreteEdge *>(ge)->haveParametrization())
+      return;
+  }
   ge->deleteMesh();
   ge->meshStatistics.status = GEdge::PENDING;
   ge->correspondingVertices.clear();
@@ -358,7 +341,7 @@ static void printFandPrimitive(int tag, std::vector<IntPoint> &Points)
   FILE *f = Fopen(name, "w");
   if(!f) return;
   double l = 0;
-  for (unsigned int i = 0; i < Points.size(); i++){
+  for (std::size_t i = 0; i < Points.size(); i++){
     const IntPoint &P = Points[i];
     if(i) l += (P.t - Points[i-1].t) * P.xp;
     fprintf(f, "%g %g %g %g %g\n", P.t, P.xp/P.lc, P.p, P.lc, l);
@@ -380,7 +363,7 @@ static void filterPoints(GEdge *ge, int nMinimumPoints)
 {
   if(ge->mesh_vertices.empty()) return;
   if(ge->meshAttributes.method == MESH_TRANSFINITE) return;
-  // if(ge->mesh_vertices.size() <= 3) return;
+
   bool forceOdd = false;
   if((ge->meshAttributes.method != MESH_TRANSFINITE ||
       CTX::instance()->mesh.flexibleTransfinite) &&
@@ -390,9 +373,11 @@ static void filterPoints(GEdge *ge, int nMinimumPoints)
     }
   }
 
+  if(!ge->getBeginVertex() || !ge->getEndVertex()) return;
+
   MVertex *v0 = ge->getBeginVertex()->mesh_vertices[0];
   std::vector<std::pair<double, MVertex *> > lengths;
-  for(unsigned int i = 0; i < ge->mesh_vertices.size(); i++) {
+  for(std::size_t i = 0; i < ge->mesh_vertices.size(); i++) {
     MEdgeVertex *v = dynamic_cast<MEdgeVertex *>(ge->mesh_vertices[i]);
     if(!v) {
       Msg::Error("in 1D mesh filterPoints");
@@ -454,7 +439,8 @@ static void filterPoints(GEdge *ge, int nMinimumPoints)
 static void createPoints(GVertex *gv, GEdge *ge, BoundaryLayerField *blf,
                          std::vector<MVertex *> &v, const SVector3 &dir)
 {
-#if defined(HAVE_ANN)
+  if(!ge->getBeginVertex() || !ge->getEndVertex()) return;
+
   const double hwall = blf->hwall(gv->tag());
   double L = hwall;
   double LEdge = distance(ge->getBeginVertex()->mesh_vertices[0],
@@ -470,14 +456,12 @@ static void createPoints(GVertex *gv, GEdge *ge, BoundaryLayerField *blf,
     int ith = v.size();
     L += hwall * std::pow(blf->ratio, ith);
   }
-#endif
 }
 
 static void addBoundaryLayerPoints(GEdge *ge, double &t_begin, double &t_end,
                                    std::vector<MVertex *> &_addBegin,
                                    std::vector<MVertex *> &_addEnd)
 {
-#if defined(HAVE_ANN)
   _addBegin.clear();
   _addEnd.clear();
 
@@ -488,6 +472,8 @@ static void addBoundaryLayerPoints(GEdge *ge, double &t_begin, double &t_end,
 
   if(n == 0) return;
 
+  if(!ge->getBeginVertex() || !ge->getEndVertex()) return;
+
   // Check if edge is a BL edge
   for(int i = 0; i < n; ++i) {
     Field *bl_field = fields->get(fields->getBoundaryLayerField(i));
@@ -538,7 +524,6 @@ static void addBoundaryLayerPoints(GEdge *ge, double &t_begin, double &t_end,
       if(!_addEnd.empty()) _addEnd[_addEnd.size() - 1]->getParameter(0, t_end);
     }
   }
-#endif
 }
 
 void meshGEdge::operator()(GEdge *ge)
@@ -558,7 +543,6 @@ void meshGEdge::operator()(GEdge *ge)
   ge->model()->setCurrentMeshEntity(ge);
 
   if(ge->degenerate(1)) return;
-  // if(ge->geomType() == GEntity::DiscreteCurve) return;
   if(ge->geomType() == GEntity::BoundaryLayerCurve) return;
   if(ge->meshAttributes.method == MESH_NONE) return;
   if(CTX::instance()->mesh.meshOnlyVisible && !ge->getVisibility()) return;
@@ -706,8 +690,8 @@ void meshGEdge::operator()(GEdge *ge)
   std::vector<MVertex *> &mesh_vertices = ge->mesh_vertices;
 
   GPoint beg_p, end_p;
-  if(!ge->getBeginVertex() && !ge->getEndVertex()) {
-    Msg::Warning("Skipping curve with no begin nor end vertex");
+  if(!ge->getBeginVertex() || !ge->getEndVertex()) {
+    Msg::Warning("Skipping curve with no begin or end point");
     return;
   }
   else if(ge->getBeginVertex() == ge->getEndVertex() &&
@@ -759,7 +743,7 @@ void meshGEdge::operator()(GEdge *ge)
     std::vector<MVertex *> vv;
     vv.insert(vv.end(), _addBegin.begin(), _addBegin.end());
     vv.insert(vv.end(), mesh_vertices.begin(), mesh_vertices.end());
-    for(unsigned int i = 0; i < _addEnd.size(); i++)
+    for(std::size_t i = 0; i < _addEnd.size(); i++)
       vv.push_back(_addEnd[_addEnd.size() - 1 - i]);
     //    vv.insert(vv.end(), _addEnd.rend(), _addEnd.rbegin());
     mesh_vertices = vv;
@@ -795,6 +779,6 @@ void orientMeshGEdge::operator()(GEdge *ge)
 {
   // apply user-specified mesh orientation constraints
   if(ge->meshAttributes.reverseMesh)
-    for(unsigned int k = 0; k < ge->getNumMeshElements(); k++)
+    for(std::size_t k = 0; k < ge->getNumMeshElements(); k++)
       ge->getMeshElement(k)->reverse();
 }
