@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <stdlib.h>
 #include "GmshMessage.h"
@@ -131,30 +131,6 @@ double NewGetLc(BDS_Point *p1, BDS_Point *p2, GFace *f)
   return linearLength / l;
 }
 
-void computeMeshSizeFieldAccuracy(GFace *gf, BDS_Mesh &m, double &avg,
-                                  double &max_e, double &min_e, int &nE,
-                                  int &GS)
-{
-  std::vector<BDS_Edge *>::const_iterator it = m.edges.begin();
-  avg = 0.0;
-  min_e = 1.e22;
-  max_e = 0;
-  nE = 0;
-  GS = 0;
-  while(it != m.edges.end()) {
-    if(!(*it)->deleted) {
-      double const lone = NewGetLc(*it, gf);
-      if(lone > 1.0 / std::sqrt(2.0) && lone < std::sqrt(2.0)) GS++;
-      avg += lone > 1 ? (1. / lone) - 1. : lone - 1.;
-      max_e = std::max(max_e, lone);
-      min_e = std::min(min_e, lone);
-      nE++;
-    }
-    ++it;
-  }
-  avg = 100 * std::exp(1.0 / nE * avg);
-}
-
 // SWAP TESTS i.e. tell if swap should be done
 
 static bool edgeSwapTestAngle(BDS_Edge *e, double min_cos)
@@ -383,7 +359,7 @@ static void splitEdgePass(GFace *gf, BDS_Mesh &m, double MAXE_, int &nb_split,
 
   bool faceDiscrete = gf->geomType() == GEntity::DiscreteSurface;
 
-  for(unsigned int i = 0; i < edges.size(); ++i) {
+  for(std::size_t i = 0; i < edges.size(); ++i) {
     BDS_Edge *e = edges[i].second;
     BDS_Point *mid = NULL;
     if(!e->deleted) {
@@ -422,7 +398,7 @@ static void splitEdgePass(GFace *gf, BDS_Mesh &m, double MAXE_, int &nb_split,
     mids[i] = mid;
   }
 
-  for(unsigned int i = 0; i < edges.size(); ++i) {
+  for(std::size_t i = 0; i < edges.size(); ++i) {
     BDS_Edge *e = edges[i].second;
     if(!e->deleted) {
       BDS_Point *mid = mids[i];
@@ -512,7 +488,7 @@ void collapseEdgePass(GFace *gf, BDS_Mesh &m, double MINE_, int MAXNP,
 
   std::sort(edges.begin(), edges.end(), edges_sort);
 
-  for(unsigned int i = 0; i < edges.size(); i++) {
+  for(std::size_t i = 0; i < edges.size(); i++) {
     BDS_Edge *e = edges[i].second;
     if(!e->deleted) {
       double lone1 = 0.;
@@ -726,8 +702,8 @@ void refineMeshBDS(GFace *gf, BDS_Mesh &m, const int NIT,
   // classify correctly the embedded vertices use a negative model
   // face number to avoid mesh motion
   if(recoverMapInv) {
-    std::set<GVertex *> emb_vertx = gf->embeddedVertices();
-    std::set<GVertex *>::iterator itvx = emb_vertx.begin();
+    std::set<GVertex *, GEntityLessThan> emb_vertx = gf->embeddedVertices();
+    std::set<GVertex *, GEntityLessThan>::iterator itvx = emb_vertx.begin();
     while(itvx != emb_vertx.end()) {
       MVertex *v = *((*itvx)->mesh_vertices.begin());
       std::map<MVertex *, BDS_Point *>::iterator itp = recoverMapInv->find(v);
@@ -1060,7 +1036,7 @@ int solveInvalidPeriodic(
 
   std::set<BDS_Edge *, EdgeLessThan> toSplit;
   invalidEdgesPeriodic(m, recoverMap, toSplit);
-  std::set<BDS_Edge *>::iterator ite = toSplit.begin();
+  std::set<BDS_Edge *, EdgeLessThan>::iterator ite = toSplit.begin();
 
   Msg::Debug("%d edges of the initial mesh are going to be split",
              toSplit.size());
@@ -1108,7 +1084,7 @@ BDS_Mesh *gmsh2BDS(std::list<GFace *> &l)
     GFace *gf = *it;
     m->add_geom(gf->tag(), 2);
     BDS_GeomEntity *g2 = m->get_geom(gf->tag(), 2);
-    for(unsigned int i = 0; i < gf->triangles.size(); i++) {
+    for(std::size_t i = 0; i < gf->triangles.size(); i++) {
       MTriangle *e = gf->triangles[i];
       BDS_Point *p[3];
       for(int j = 0; j < 3; j++) {
