@@ -41,23 +41,25 @@ typedef unsigned long intptr_t;
 #include "drawContext.h"
 #endif
 
-
-static inline int computeTetGenVersion2(uint32_t v1, uint32_t* v2Choices, const int iface2){
+#if 0
+static int computeTetGenVersion2(uint32_t v1, uint32_t* v2Choices,
+                                 const int iface2)
+{
   int i;
-  for (i=0; i<3; i++) {
-      if(v1==v2Choices[i]){
-        break;
-      }
+  for (i = 0; i < 3; i++) {
+    if(v1 == v2Choices[i]){
+      break;
+    }
   }
 
-  if(i==3)
-    Msg::Error("should never happen (file:%s line:%d)\n", __FILE__, __LINE__);
-  
+  if(i == 3)
+    Msg::Error("Should never happen (file:%s line:%d)", __FILE__, __LINE__);
+
   // version%4 : corresponding face in adjacent tet
   // version/4 : which of the 3 rotation of the facet the tetrahedra has...
-  return 4*i + iface2;
+  return 4 * i + iface2;
 }
-
+#endif
 
 namespace tetgenBR {
 
@@ -158,7 +160,7 @@ namespace tetgenBR {
       for(std::vector<GFace *>::const_iterator it = f.begin(); it != f.end();
           ++it) {
         GFace *gf = *it;
-        for(unsigned int i = 0; i < gf->triangles.size(); i++) {
+        for(std::size_t i = 0; i < gf->triangles.size(); i++) {
           MVertex *v0 = gf->triangles[i]->getVertex(0);
           MVertex *v1 = gf->triangles[i]->getVertex(1);
           MVertex *v2 = gf->triangles[i]->getVertex(2);
@@ -167,7 +169,7 @@ namespace tetgenBR {
           all.insert(v2);
         }
         if(_sqr){
-          for(unsigned int i = 0; i < gf->quadrangles.size(); i++) {
+          for(std::size_t i = 0; i < gf->quadrangles.size(); i++) {
             MVertex *v0 = gf->quadrangles[i]->getVertex(0);
             MVertex *v1 = gf->quadrangles[i]->getVertex(1);
             MVertex *v2 = gf->quadrangles[i]->getVertex(2);
@@ -192,7 +194,7 @@ namespace tetgenBR {
       for(std::vector<GEdge *>::const_iterator it = e.begin(); it != e.end();
           ++it) {
         GEdge *ge = *it;
-        for(unsigned int i = 0; i < ge->lines.size(); i++) {
+        for(std::size_t i = 0; i < ge->lines.size(); i++) {
           all.insert(ge->lines[i]->getVertex(0));
           all.insert(ge->lines[i]->getVertex(1));
         }
@@ -201,7 +203,7 @@ namespace tetgenBR {
       for(std::vector<GVertex *>::const_iterator it = v.begin(); it != v.end();
           ++it) {
         GVertex *gv = *it;
-        for(unsigned int i = 0; i < gv->points.size(); i++) {
+        for(std::size_t i = 0; i < gv->points.size(); i++) {
           all.insert(gv->points[i]->getVertex(0));
         }
       }
@@ -215,7 +217,7 @@ namespace tetgenBR {
     // Store all coordinates of the vertices as these will be pertubated in
     // function delaunayTriangulation
     std::map<MVertex *, SPoint3> originalCoordinates;
-    for(unsigned int i = 0; i < _vertices.size(); i++) {
+    for(std::size_t i = 0; i < _vertices.size(); i++) {
       MVertex *v = _vertices[i];
       originalCoordinates[v] = v->point();
     }
@@ -232,7 +234,7 @@ namespace tetgenBR {
       REAL x, y, z;
 
       // Read the points.
-      for(unsigned int i = 0; i < _vertices.size(); i++) {
+      for(std::size_t i = 0; i < _vertices.size(); i++) {
         makepoint(&pointloop, UNUSEDVERTEX);
         // Read the point coordinates.
         x = pointloop[0] = _vertices[i]->x();
@@ -278,7 +280,7 @@ namespace tetgenBR {
     idx2verlist[0] = dummypoint; // Let 0th-entry be dummypoint.
     // Index the vertices, starting at 1 (vertex index 0 is used as special code
     // in tetgenBR in case of failure)
-    for(unsigned int i = 0; i < _vertices.size(); i++) {
+    for(std::size_t i = 0; i < _vertices.size(); i++) {
       _vertices[i]->setIndex(i + 1);
     }
 
@@ -297,7 +299,7 @@ namespace tetgenBR {
 
       // Allocate an array that maps each vertex to its adjacent tets.
       ver2tetarray = new tetrahedron[_vertices.size() + in->firstnumber];
-      for(unsigned int i = 0; i < _vertices.size() + in->firstnumber; i++) {
+      for(std::size_t i = 0; i < _vertices.size() + in->firstnumber; i++) {
         setpointtype(idx2verlist[i], VOLVERTEX); // initial type.
         ver2tetarray[i] = NULL;
       }
@@ -307,7 +309,7 @@ namespace tetgenBR {
 #if 0
       /*  N E W   V E R S I O N	  */
       std::vector<triface> ts( tets.size() );
-      for(unsigned int i = 0; i < tets.size(); i++) {
+      for(std::size_t i = 0; i < tets.size(); i++) {
 	point p[4];
 	// index tetrahedra in order to have access to neighbors ids.
 	tets[i]->tet()->forceNum(i+1);
@@ -320,28 +322,28 @@ namespace tetgenBR {
           // we can make this in parallel, iterations are totally independent
       for (uint64_t i = 0; i < tets.size(); i++) {
 	triface tf1 = ts[i];
-	
+
 	for (tf1.ver=0; tf1.ver<4; tf1.ver++){
 	  uint64_t neigh = tets[i]->getNeigh(tf1.ver)->tet()->getNum() - 1;
 	  triface tf2 = ts[neigh];
 	  int iface2 = tf1.ver;
-	  
+
 	  int face2[3] = {
 	    tets[i]->getVertex(faces_tetra(tf1.ver),0)->getIndex(),
 	    tets[i]->getVertex(faces_tetra(tf1.ver),1)->getIndex(),
 	    tets[i]->getVertex(faces_tetra(tf1.ver),2)->getIndex()};
-	  
+
 	  tf2.ver = computeTetGenVersion2(faces2[0], face2, iface2);
 	  bond(tf1,tf2);
 	}
       }
-      
+
 #else
-      
+
       /*  N E W   V E R S I O N	  */
-      
+
       // Create the tetrahedra and connect those that share a common face.
-      for(unsigned int i = 0; i < tets.size(); i++) {
+      for(std::size_t i = 0; i < tets.size(); i++) {
         // Get the four vertices.
         for(int j = 0; j < 4; j++) {
           p[j] = idx2verlist[tets[i]->getVertex(j)->getIndex()];
@@ -488,7 +490,7 @@ namespace tetgenBR {
       hullsize = tetrahedrons->items - hullsize;
 
       delete[] ver2tetarray;
-      for(unsigned int i = 0; i < tets.size(); i++) delete tets[i];
+      for(std::size_t i = 0; i < tets.size(); i++) delete tets[i];
       tets.clear(); // Release all memory in this vector.
     }
 #endif
@@ -506,7 +508,7 @@ namespace tetgenBR {
       for(std::vector<GFace *>::const_iterator it = f_list.begin();
           it != f_list.end(); ++it) {
         GFace *gf = *it;
-        for(unsigned int i = 0; i < gf->triangles.size(); i++) {
+        for(std::size_t i = 0; i < gf->triangles.size(); i++) {
           for(int j = 0; j < 3; j++) {
             p[j] = idx2verlist[gf->triangles[i]->getVertex(j)->getIndex()];
             if(pointtype(p[j]) == VOLVERTEX) {
@@ -574,7 +576,7 @@ namespace tetgenBR {
       for(std::vector<GEdge *>::const_iterator it = e_list.begin();
           it != e_list.end(); ++it) {
         GEdge *ge = *it;
-        for(unsigned int i = 0; i < ge->lines.size(); i++) {
+        for(std::size_t i = 0; i < ge->lines.size(); i++) {
           for(int j = 0; j < 2; j++) {
             p[j] = idx2verlist[ge->lines[i]->getVertex(j)->getIndex()];
             setpointtype(p[j], RIDGEVERTEX);
@@ -748,7 +750,7 @@ namespace tetgenBR {
     {
       // Write mesh into to GRegion.
 
-      Msg::Info("Writing to GRegion...");
+      Msg::Debug("Writing to GRegion...");
 
       point p[4];
 
@@ -883,7 +885,7 @@ namespace tetgenBR {
       }
 
       if(!_extras.empty())
-        Msg::Info("We add %d steiner points...", _extras.size());
+        Msg::Info("Added %d steiner points", _extras.size());
 
       if(l_edges.size() > 0) {
         // There are Steiner points on segments!
@@ -904,9 +906,9 @@ namespace tetgenBR {
             }
           }
           assert(ge != NULL);
-          // Msg::Info("Steiner points exist on GEdge %d", ge->tag());
+          Msg::Info("Steiner points exist on curve %d", ge->tag());
           // Delete the old triangles.
-          for(unsigned int i = 0; i < ge->lines.size(); i++)
+          for(std::size_t i = 0; i < ge->lines.size(); i++)
             delete ge->lines[i];
           ge->lines.clear();
           ge->deleteVertexArrays();
@@ -951,8 +953,8 @@ namespace tetgenBR {
           }
           assert(gf != NULL);
           // Delete the old triangles.
-          Msg::Info("Steiner points exist on GFace %d", gf->tag());
-          for(unsigned int i = 0; i < gf->triangles.size(); i++)
+          Msg::Info("Steiner points exist on surface %d", gf->tag());
+          for(std::size_t i = 0; i < gf->triangles.size(); i++)
             delete gf->triangles[i];
           gf->triangles.clear();
           gf->deleteVertexArrays();
@@ -1029,9 +1031,9 @@ namespace tetgenBR {
     }
 
     // delete 8 new enclosing box vertices added in delaunayMeshIn3d
-    for(unsigned int i = _vertices.size() - 8; i < _vertices.size(); i++)
+    for(std::size_t i = _vertices.size() - 8; i < _vertices.size(); i++)
       delete _vertices[i];
-    
+
     return true;
   }
 
@@ -1261,7 +1263,7 @@ bool meshGRegionBoundaryRecovery(GRegion *gr, splitQuadRecovery *sqr)
       std::vector<GFace *> f = gr->faces();
       for(std::vector<GFace *>::iterator it = f.begin(); it != f.end(); ++it) {
         GFace *gf = *it;
-        for(unsigned int i = 0; i < gf->triangles.size(); i++) {
+        for(std::size_t i = 0; i < gf->triangles.size(); i++) {
           for(int j = 0; j < 3; j++) {
             MVertex *v = gf->triangles[i]->getVertex(j);
             all[v->getIndex()] = v;
@@ -1272,7 +1274,7 @@ bool meshGRegionBoundaryRecovery(GRegion *gr, splitQuadRecovery *sqr)
       for(std::vector<GEdge *>::const_iterator it = e.begin(); it != e.end();
           ++it) {
         GEdge *ge = *it;
-        for(unsigned int i = 0; i < ge->lines.size(); i++) {
+        for(std::size_t i = 0; i < ge->lines.size(); i++) {
           for(int j = 0; j < 2; j++) {
             MVertex *v = ge->lines[i]->getVertex(j);
             all[v->getIndex()] = v;
@@ -1283,12 +1285,12 @@ bool meshGRegionBoundaryRecovery(GRegion *gr, splitQuadRecovery *sqr)
       for(std::vector<GVertex *>::const_iterator it = v.begin(); it != v.end();
           ++it) {
         GVertex *gv = *it;
-        for(unsigned int i = 0; i < gv->points.size(); i++) {
+        for(std::size_t i = 0; i < gv->points.size(); i++) {
           MVertex *v = gv->points[i]->getVertex(0);
           all[v->getIndex()] = v;
         }
       }
-      for(unsigned int i = 0; i < gr->mesh_vertices.size(); i++) {
+      for(std::size_t i = 0; i < gr->mesh_vertices.size(); i++) {
         MVertex *v = gr->mesh_vertices[i];
         all[v->getIndex()] = v;
       }
