@@ -5,6 +5,10 @@
 //
 // Contributed by Anthony Royer.
 
+// FIXME: The partitioning code should be updated to
+// - use int for partition tags (to match the type for other entities in Gmsh)
+// - use size_t for element/node tags, and thus the graph
+
 #include <vector>
 #include <set>
 #include <sstream>
@@ -17,6 +21,7 @@
 #include "GmshConfig.h"
 #include "GmshMessage.h"
 #include "GModel.h"
+#include "ElementType.h"
 
 // TODO C++11 remove this nasty stuff
 #if __cplusplus >= 201103L
@@ -506,7 +511,7 @@ static int MakeGraph(GModel *const model, Graph &graph, int selectDim)
   if(selectDim < 0) {
     graph.ne(model->getNumMeshElements());
     graph.nn(model->getNumMeshVertices());
-    graph.dim(model->getDim());
+    graph.dim(model->getMeshDim());
     graph.elementResize(graph.ne());
     graph.vertexResize(model->getMaxVertexNumber());
     graph.eptrResize(graph.ne() + 1);
@@ -520,7 +525,7 @@ static int MakeGraph(GModel *const model, Graph &graph, int selectDim)
     model->getEntities(entities);
 
     std::set<MVertex *> vertices;
-    for(unsigned int i = 0; i < entities.size(); i++) {
+    for(std::size_t i = 0; i < entities.size(); i++) {
       if(entities[i]->dim() == selectDim) {
         switch(entities[i]->dim()) {
         case 3: tmp->add(static_cast<GRegion *>(entities[i])); break;
@@ -529,8 +534,8 @@ static int MakeGraph(GModel *const model, Graph &graph, int selectDim)
         case 0: tmp->add(static_cast<GVertex *>(entities[i])); break;
         default: break;
         }
-        for(unsigned int j = 0; j < entities[i]->getNumMeshElements(); j++) {
-          for(unsigned int k = 0;
+        for(std::size_t j = 0; j < entities[i]->getNumMeshElements(); j++) {
+          for(std::size_t k = 0;
               k < entities[i]->getMeshElement(j)->getNumVertices(); k++) {
             vertices.insert(entities[i]->getMeshElement(j)->getVertex(k));
           }
@@ -540,7 +545,7 @@ static int MakeGraph(GModel *const model, Graph &graph, int selectDim)
 
     graph.ne(tmp->getNumMeshElements());
     graph.nn(vertices.size());
-    graph.dim(tmp->getDim());
+    graph.dim(tmp->getMeshDim());
     graph.elementResize(graph.ne());
     graph.vertexResize(model->getMaxVertexNumber());
     graph.eptrResize(graph.ne() + 1);
@@ -703,7 +708,7 @@ static int PartitionGraph(Graph &graph)
     switch(metisError) {
     case METIS_OK: break;
     case METIS_ERROR_INPUT: Msg::Error("METIS input error"); return 1;
-    case METIS_ERROR_MEMORY: Msg::Error("METIS memoty error"); return 1;
+    case METIS_ERROR_MEMORY: Msg::Error("METIS memory error"); return 1;
     case METIS_ERROR:
     default: Msg::Error("METIS error"); return 1;
     }
@@ -777,8 +782,7 @@ void removeVerticesEntity(ITERATOR it_beg, ITERATOR it_end)
 {
   for(ITERATOR it = it_beg; it != it_end; ++it) {
     for(std::size_t i = 0; i < (*it)->getNumMeshElements(); i++) {
-      for(GModel::size_type j = 0;
-          j < (*it)->getMeshElement(i)->getNumVertices(); j++) {
+      for(std::size_t j = 0; j < (*it)->getMeshElement(i)->getNumVertices(); j++) {
         (*it)->getMeshElement(i)->getVertex(j)->setEntity(0);
       }
     }
@@ -906,7 +910,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
 
         if(vertex->getNumMeshElements() > 1) {
           ret = true;
-          for(unsigned int i = 0; i < vertex->getNumMeshElements(); i++) {
+          for(std::size_t i = 0; i < vertex->getNumMeshElements(); i++) {
             // Create the new partitionVertex
             partitionVertex *pvertex = new partitionVertex(
               model, ++elementaryNumber, vertex->getPartitions());
@@ -949,7 +953,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
     Graph graph(model);
     graph.ne(model->getNumMeshElements(1));
     graph.nn(model->getNumMeshVertices(1));
-    graph.dim(model->getDim());
+    graph.dim(model->getMeshDim());
     graph.elementResize(graph.ne());
     graph.vertexResize(model->getMaxVertexNumber());
     graph.eptrResize(graph.ne() + 1);
@@ -1002,7 +1006,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
             }
           }
 
-          for(unsigned int i = 0; i < connectedElements.size(); i++) {
+          for(std::size_t i = 0; i < connectedElements.size(); i++) {
             // Create the new partitionEdge
             partitionEdge *pedge = new partitionEdge(
               model, ++elementaryNumber, 0, 0, edge->getPartitions());
@@ -1045,7 +1049,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
     Graph graph(model);
     graph.ne(model->getNumMeshElements(2));
     graph.nn(model->getNumMeshVertices(2));
-    graph.dim(model->getDim());
+    graph.dim(model->getMeshDim());
     graph.elementResize(graph.ne());
     graph.vertexResize(model->getMaxVertexNumber());
     graph.eptrResize(graph.ne() + 1);
@@ -1098,7 +1102,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
             }
           }
 
-          for(unsigned int i = 0; i < connectedElements.size(); i++) {
+          for(std::size_t i = 0; i < connectedElements.size(); i++) {
             // Create the new partitionFace
             partitionFace *pface = new partitionFace(model, ++elementaryNumber,
                                                      face->getPartitions());
@@ -1142,7 +1146,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
     Graph graph(model);
     graph.ne(model->getNumMeshElements(3));
     graph.nn(model->getNumMeshVertices(3));
-    graph.dim(model->getDim());
+    graph.dim(model->getMeshDim());
     graph.elementResize(graph.ne());
     graph.vertexResize(model->getMaxVertexNumber());
     graph.eptrResize(graph.ne() + 1);
@@ -1195,7 +1199,7 @@ dividedNonConnectedEntities(GModel *const model, int dim,
 
         if(connectedElements.size() > 1) {
           ret = true;
-          for(unsigned int i = 0; i < connectedElements.size(); i++) {
+          for(std::size_t i = 0; i < connectedElements.size(); i++) {
             // Create the new partitionRegion
             partitionRegion *pregion = new partitionRegion(
               model, ++elementaryNumber, region->getPartitions());
@@ -1419,7 +1423,7 @@ static MElement *getReferenceElement(
 
   // Take only the elements having the less partition in commun. For exemple we
   // take (1,2) and (3,8) but not (2,5,9) or (1,4,5,7)
-  for(unsigned int i = 0; i < elementPairs.size(); i++) {
+  for(std::size_t i = 0; i < elementPairs.size(); i++) {
     if(min > elementPairs[i].second.size()) {
       minSizeElementPairs.clear();
       min = elementPairs[i].second.size();
@@ -1433,7 +1437,7 @@ static MElement *getReferenceElement(
   // Check if the element separated different partitions
   if(minSizeElementPairs.size() == elementPairs.size()) {
     bool isEqual = true;
-    for(unsigned int i = 1; i < minSizeElementPairs.size(); i++) {
+    for(std::size_t i = 1; i < minSizeElementPairs.size(); i++) {
       if(minSizeElementPairs[i].second != minSizeElementPairs[0].second) {
         isEqual = false;
         break;
@@ -1444,7 +1448,7 @@ static MElement *getReferenceElement(
 
   while(minSizeElementPairs.size() > 1) {
     min = std::numeric_limits<unsigned int>::max();
-    for(unsigned int i = 0; i < minSizeElementPairs.size(); i++) {
+    for(std::size_t i = 0; i < minSizeElementPairs.size(); i++) {
       // The partition vector is sorted thus we can check only the first element
       if(minSizeElementPairs[i].second.size() == 0)
         return minSizeElementPairs[0].first;
@@ -1453,7 +1457,7 @@ static MElement *getReferenceElement(
       }
     }
 
-    for(unsigned int i = 0; i < minSizeElementPairs.size(); i++) {
+    for(std::size_t i = 0; i < minSizeElementPairs.size(); i++) {
       if(min == minSizeElementPairs[i].second[0]) {
         minSizeElementPairs[i].second.erase(
           minSizeElementPairs[i].second.begin());
@@ -1477,8 +1481,8 @@ static void getPartitionInVector(
   const std::vector<std::pair<MElement *, std::vector<unsigned int> > >
     &boundaryPair)
 {
-  for(unsigned int i = 0; i < boundaryPair.size(); i++) {
-    for(unsigned int j = 0; j < boundaryPair[i].second.size(); j++) {
+  for(std::size_t i = 0; i < boundaryPair.size(); i++) {
+    for(std::size_t j = 0; j < boundaryPair[i].second.size(); j++) {
       if(std::find(partitions.begin(), partitions.end(),
                    boundaryPair[i].second[j]) == partitions.end()) {
         partitions.push_back(boundaryPair[i].second[j]);
@@ -1822,7 +1826,7 @@ static void CreatePartitionTopology(
   GModel *const model,
   const std::vector<std::set<MElement *> > &boundaryElements, Graph &meshGraph)
 {
-  const int meshDim = model->getDim();
+  const int meshDim = model->getMeshDim();
   hashmap<MElement *, GEntity *> elementToEntity;
   fillElementToEntity(model, elementToEntity, -1);
   assignNewEntityBRep(meshGraph, elementToEntity);
@@ -1870,7 +1874,7 @@ static void CreatePartitionTopology(
                                 elementToEntity, numFaceEntity);
       if(pf) {
         std::map<GEntity *, MElement *> boundaryEntityAndRefElement;
-        for(unsigned int i = 0; i < it->second.size(); i++)
+        for(std::size_t i = 0; i < it->second.size(); i++)
           boundaryEntityAndRefElement.insert(std::pair<GEntity *, MElement *>(
             elementToEntity[it->second[i].first], it->second[i].first));
 
@@ -1963,7 +1967,7 @@ static void CreatePartitionTopology(
                                 elementToEntity, numEdgeEntity);
       if(pe) {
         std::map<GEntity *, MElement *> boundaryEntityAndRefElement;
-        for(unsigned int i = 0; i < it->second.size(); i++) {
+        for(std::size_t i = 0; i < it->second.size(); i++) {
           boundaryEntityAndRefElement.insert(std::pair<GEntity *, MElement *>(
             elementToEntity[it->second[i].first], it->second[i].first));
         }
@@ -2050,7 +2054,7 @@ static void CreatePartitionTopology(
                                 elementToEntity, numVertexEntity);
       if(pv) {
         std::map<GEntity *, MElement *> boundaryEntityAndRefElement;
-        for(unsigned int i = 0; i < it->second.size(); i++)
+        for(std::size_t i = 0; i < it->second.size(); i++)
           boundaryEntityAndRefElement.insert(std::pair<GEntity *, MElement *>(
             elementToEntity[it->second[i].first], it->second[i].first));
 
@@ -2246,6 +2250,11 @@ int PartitionMesh(GModel *const model)
   graph.nparts(CTX::instance()->mesh.numPartitions);
   if(PartitionGraph(graph)) return 1;
 
+  std::vector<int> elmCount[TYPE_MAX_NUM + 1];
+  for (int i = 0; i < TYPE_MAX_NUM + 1; i++) {
+    elmCount[i].resize(CTX::instance()->mesh.numPartitions, 0);
+  }
+
   // Assign partitions to elements
   hashmap<MElement *, unsigned int> elmToPartition;
   for(unsigned int i = 0; i < graph.ne(); i++) {
@@ -2253,6 +2262,7 @@ int PartitionMesh(GModel *const model)
       if(graph.nparts() > 1) {
         elmToPartition.insert(std::pair<MElement *, unsigned int>(
           graph.element(i), graph.partition(i) + 1));
+        elmCount[graph.element(i)->getType()][graph.partition(i)]++;
         // Should be removed
         graph.element(i)->setPartition(graph.partition(i) + 1);
       }
@@ -2272,6 +2282,24 @@ int PartitionMesh(GModel *const model)
   double t2 = Cpu();
   Msg::StatusBar(true, "Done partitioning mesh (%g s)", t2 - t1);
 
+  for(std::size_t i = 0; i < TYPE_MAX_NUM + 1; i++) {
+    std::vector<int> &count = elmCount[i];
+    int minCount = std::numeric_limits<int>::max();
+    int maxCount = 0;
+    int totCount = 0;
+    for (std::size_t j = 0; j < count.size(); j++) {
+      minCount = std::min(count[j], minCount);
+      maxCount = std::max(count[j], maxCount);
+      totCount += count[j];
+    }
+    if(totCount > 0) {
+      Msg::Info(" - Repartition of %d %s(s): %d(min) %d(max) %g(avg)",
+                totCount, ElementType::nameOfParentType(i).c_str(),
+                minCount, maxCount,
+                totCount / (double)CTX::instance()->mesh.numPartitions);
+    }
+  }
+
   if(CTX::instance()->mesh.partitionCreateTopology) {
     Msg::StatusBar(true, "Creating partition topology...");
     std::vector<std::set<MElement *> > boundaryElements =
@@ -2340,7 +2368,7 @@ int UnpartitionMesh(GModel *const model)
                        pvertex->points.end());
       }
       else {
-        for(unsigned int j = 0; j < pvertex->points.size(); j++)
+        for(std::size_t j = 0; j < pvertex->points.size(); j++)
           delete pvertex->points[j];
       }
       pvertex->points.clear();
@@ -2360,7 +2388,7 @@ int UnpartitionMesh(GModel *const model)
         assignToParent(verts, pedge, pedge->lines.begin(), pedge->lines.end());
       }
       else {
-        for(unsigned int j = 0; j < pedge->lines.size(); j++)
+        for(std::size_t j = 0; j < pedge->lines.size(); j++)
           delete pedge->lines[j];
       }
       pedge->lines.clear();
@@ -2390,9 +2418,9 @@ int UnpartitionMesh(GModel *const model)
                        pface->quadrangles.end());
       }
       else {
-        for(unsigned int j = 0; j < pface->triangles.size(); j++)
+        for(std::size_t j = 0; j < pface->triangles.size(); j++)
           delete pface->triangles[j];
-        for(unsigned int j = 0; j < pface->quadrangles.size(); j++)
+        for(std::size_t j = 0; j < pface->quadrangles.size(); j++)
           delete pface->quadrangles[j];
       }
       pface->triangles.clear();
@@ -2429,15 +2457,15 @@ int UnpartitionMesh(GModel *const model)
                        pregion->trihedra.end());
       }
       else {
-        for(unsigned int j = 0; j < pregion->tetrahedra.size(); j++)
+        for(std::size_t j = 0; j < pregion->tetrahedra.size(); j++)
           delete pregion->tetrahedra[j];
-        for(unsigned int j = 0; j < pregion->hexahedra.size(); j++)
+        for(std::size_t j = 0; j < pregion->hexahedra.size(); j++)
           delete pregion->hexahedra[j];
-        for(unsigned int j = 0; j < pregion->prisms.size(); j++)
+        for(std::size_t j = 0; j < pregion->prisms.size(); j++)
           delete pregion->prisms[j];
-        for(unsigned int j = 0; j < pregion->pyramids.size(); j++)
+        for(std::size_t j = 0; j < pregion->pyramids.size(); j++)
           delete pregion->pyramids[j];
-        for(unsigned int j = 0; j < pregion->trihedra.size(); j++)
+        for(std::size_t j = 0; j < pregion->trihedra.size(); j++)
           delete pregion->trihedra[j];
       }
       pregion->tetrahedra.clear();
@@ -2550,8 +2578,8 @@ int ConvertOldPartitioningToNewOne(GModel *const model)
   std::set<unsigned int> partitions;
   std::vector<GEntity *> entities;
   model->getEntities(entities);
-  for(unsigned int i = 0; i < entities.size(); i++) {
-    for(unsigned int j = 0; j < entities[i]->getNumMeshElements(); j++) {
+  for(std::size_t i = 0; i < entities.size(); i++) {
+    for(std::size_t j = 0; j < entities[i]->getNumMeshElements(); j++) {
       MElement *e = entities[i]->getMeshElement(i);
       elmToPartition.insert(
         std::pair<MElement *, unsigned int>(e, e->getPartition()));
@@ -2577,6 +2605,7 @@ int ConvertOldPartitioningToNewOne(GModel *const model) { return 0; }
 int PartitionUsingThisSplit(GModel *const model, unsigned int npart,
                             hashmap<MElement *, unsigned int> &elmToPartition)
 {
+  Msg::Error("Gmsh must be compiled with METIS support to partition meshes");
   return 0;
 }
 
