@@ -84,7 +84,7 @@ static bool setBLData(MElement *el)
 static void Subdivide(GEdge *ge)
 {
   std::vector<MLine *> lines2;
-  for(unsigned int i = 0; i < ge->lines.size(); i++) {
+  for(std::size_t i = 0; i < ge->lines.size(); i++) {
     MLine *l = ge->lines[i];
     if(l->getNumVertices() == 3) {
       lines2.push_back(new MLine(l->getVertex(0), l->getVertex(2)));
@@ -98,17 +98,17 @@ static void Subdivide(GEdge *ge)
   // 2nd order meshing destroyed the ordering of the vertices on the edge
   std::sort(ge->mesh_vertices.begin(), ge->mesh_vertices.end(),
             MVertexLessThanParam());
-  for(unsigned int i = 0; i < ge->mesh_vertices.size(); i++)
+  for(std::size_t i = 0; i < ge->mesh_vertices.size(); i++)
     ge->mesh_vertices[i]->setPolynomialOrder(1);
   ge->deleteVertexArrays();
 }
 
 static void Subdivide(GFace *gf, bool splitIntoQuads, bool splitIntoHexas,
-                      faceContainer &faceVertices)
+                      faceContainer &faceVertices, bool linear)
 {
   if(!splitIntoQuads && !splitIntoHexas) {
     std::vector<MTriangle *> triangles2;
-    for(unsigned int i = 0; i < gf->triangles.size(); i++) {
+    for(std::size_t i = 0; i < gf->triangles.size(); i++) {
       MTriangle *t = gf->triangles[i];
       if(t->getNumVertices() == 6) {
         triangles2.push_back(
@@ -127,7 +127,7 @@ static void Subdivide(GFace *gf, bool splitIntoQuads, bool splitIntoHexas,
   }
 
   std::vector<MQuadrangle *> quadrangles2;
-  for(unsigned int i = 0; i < gf->quadrangles.size(); i++) {
+  for(std::size_t i = 0; i < gf->quadrangles.size(); i++) {
     MQuadrangle *q = gf->quadrangles[i];
     if(q->getNumVertices() == 9) {
       quadrangles2.push_back(new MQuadrangle(q->getVertex(0), q->getVertex(4),
@@ -143,26 +143,28 @@ static void Subdivide(GFace *gf, bool splitIntoQuads, bool splitIntoHexas,
     delete q;
   }
   if(splitIntoQuads || splitIntoHexas) {
-    for(unsigned int i = 0; i < gf->triangles.size(); i++) {
+    for(std::size_t i = 0; i < gf->triangles.size(); i++) {
       MTriangle *t = gf->triangles[i];
       if(t->getNumVertices() == 6) {
         SPoint2 pt;
         SPoint3 ptx;
-        t->pnt(0.5, 0.5, 0, ptx);
+        t->pnt(1. / 3., 1. / 3., 0., ptx);
         bool reparamOK = true;
-        for(int k = 0; k < 6; k++) {
-          SPoint2 temp;
-          reparamOK &= reparamMeshVertexOnFace(t->getVertex(k), gf, temp);
-          pt[0] += temp[0] / 6.;
-          pt[1] += temp[1] / 6.;
+        if(!linear){
+          for(int k = 0; k < 6; k++) {
+            SPoint2 temp;
+            reparamOK &= reparamMeshVertexOnFace(t->getVertex(k), gf, temp);
+            pt[0] += temp[0] / 6.;
+            pt[1] += temp[1] / 6.;
+          }
         }
         MVertex *newv;
-        if(reparamOK) {
-          GPoint gp = gf->point(pt);
-          newv = new MFaceVertex(gp.x(), gp.y(), gp.z(), gf, pt[0], pt[1]);
+        if(linear || !reparamOK) {
+          newv = new MVertex(ptx.x(), ptx.y(), ptx.z(), gf);
         }
         else {
-          newv = new MVertex(ptx.x(), ptx.y(), ptx.z(), gf);
+          GPoint gp = gf->point(pt);
+          newv = new MFaceVertex(gp.x(), gp.y(), gp.z(), gf, pt[0], pt[1]);
         }
         gf->mesh_vertices.push_back(newv);
         if(splitIntoHexas) faceVertices[t->getFace(0)].push_back(newv);
@@ -180,7 +182,7 @@ static void Subdivide(GFace *gf, bool splitIntoQuads, bool splitIntoHexas,
   }
   gf->quadrangles = quadrangles2;
 
-  for(unsigned int i = 0; i < gf->mesh_vertices.size(); i++)
+  for(std::size_t i = 0; i < gf->mesh_vertices.size(); i++)
     gf->mesh_vertices[i]->setPolynomialOrder(1);
   gf->deleteVertexArrays();
 }
@@ -191,7 +193,7 @@ static void Subdivide(GRegion *gr, bool splitIntoHexas,
   if(!splitIntoHexas) {
     // Split tets into other tets
     std::vector<MTetrahedron *> tetrahedra2;
-    for(unsigned int i = 0; i < gr->tetrahedra.size(); i++) {
+    for(std::size_t i = 0; i < gr->tetrahedra.size(); i++) {
       MTetrahedron *t = gr->tetrahedra[i];
       // FIXME: we should choose the template to maximize the quality
       if(t->getNumVertices() == 10) {
@@ -220,7 +222,7 @@ static void Subdivide(GRegion *gr, bool splitIntoHexas,
 
   // Split hexes into other hexes.
   std::vector<MHexahedron *> hexahedra2;
-  for(unsigned int i = 0; i < gr->hexahedra.size(); i++) {
+  for(std::size_t i = 0; i < gr->hexahedra.size(); i++) {
     MHexahedron *h = gr->hexahedra[i];
     if(h->getNumVertices() == 27) {
       hexahedra2.push_back(new MHexahedron(h->getVertex(0), h->getVertex(8),
@@ -258,7 +260,7 @@ static void Subdivide(GRegion *gr, bool splitIntoHexas,
 
   // Split tets into other hexes.
   if(splitIntoHexas) {
-    for(unsigned int i = 0; i < gr->tetrahedra.size(); i++) {
+    for(std::size_t i = 0; i < gr->tetrahedra.size(); i++) {
       MTetrahedron *t = gr->tetrahedra[i];
       if(t->getNumVertices() == 10) {
         std::vector<MVertex *> newv;
@@ -302,7 +304,7 @@ static void Subdivide(GRegion *gr, bool splitIntoHexas,
     }
     gr->tetrahedra.clear();
 
-    for(unsigned int i = 0; i < gr->prisms.size(); i++) {
+    for(std::size_t i = 0; i < gr->prisms.size(); i++) {
       MPrism *p = gr->prisms[i];
       if(p->getNumVertices() == 18) {
         std::vector<MVertex *> newv;
@@ -348,11 +350,11 @@ static void Subdivide(GRegion *gr, bool splitIntoHexas,
       }
     }
     gr->prisms.clear();
-    // --------------------------------------------------
-    // YAMAKAWA DIVISION OF A PYRAMID INTO 88 HEXES !!!!!
-    // --------------------------------------------------
+
+    // Yamakawa subdivision of a pyramid into 88 hexes (thanks to Tristan
+    // Carrier Baudouin!)
     std::vector<MHexahedron *> dwarfs88;
-    for(unsigned int i = 0; i < gr->pyramids.size(); i++) {
+    for(std::size_t i = 0; i < gr->pyramids.size(); i++) {
       MPyramid *p = gr->pyramids[i];
       if(p->getNumVertices() == 14) {
         subdivide_pyramid(p, gr, faceVertices, dwarfs88);
@@ -360,14 +362,11 @@ static void Subdivide(GRegion *gr, bool splitIntoHexas,
       }
     }
     gr->pyramids.clear();
-    // --------------------------------------------------
-    // ---- THANKS TO TRISTAN CARRIER BAUDOUIN ----------
-    // --------------------------------------------------
   }
   gr->hexahedra = hexahedra2;
 
   std::vector<MPrism *> prisms2;
-  for(unsigned int i = 0; i < gr->prisms.size(); i++) {
+  for(std::size_t i = 0; i < gr->prisms.size(); i++) {
     MPrism *p = gr->prisms[i];
     if(p->getNumVertices() == 18) {
       prisms2.push_back(new MPrism(p->getVertex(0), p->getVertex(6),
@@ -401,7 +400,7 @@ static void Subdivide(GRegion *gr, bool splitIntoHexas,
   gr->prisms = prisms2;
 
   std::vector<MPyramid *> pyramids2;
-  for(unsigned int i = 0; i < gr->pyramids.size(); i++) {
+  for(std::size_t i = 0; i < gr->pyramids.size(); i++) {
     if(splitIntoHexas) {
       Msg::Error("Full hexahedron subdivision is not implemented for pyramids");
       return;
@@ -452,7 +451,7 @@ static void Subdivide(GRegion *gr, bool splitIntoHexas,
   }
   gr->pyramids = pyramids2;
 
-  for(unsigned int i = 0; i < gr->mesh_vertices.size(); i++)
+  for(std::size_t i = 0; i < gr->mesh_vertices.size(); i++)
     gr->mesh_vertices[i]->setPolynomialOrder(1);
   gr->deleteVertexArrays();
 }
@@ -460,9 +459,6 @@ static void Subdivide(GRegion *gr, bool splitIntoHexas,
 void RefineMesh(GModel *m, bool linear, bool splitIntoQuads,
                 bool splitIntoHexas)
 {
-  //  splitIntoQuads = true;
-  //  splitIntoHexas = true;
-
   Msg::StatusBar(true, "Refining mesh...");
   double t1 = Cpu();
 
@@ -477,10 +473,8 @@ void RefineMesh(GModel *m, bool linear, bool splitIntoQuads,
   // mesh
   for(GModel::eiter it = m->firstEdge(); it != m->lastEdge(); ++it)
     Subdivide(*it);
-  for(GModel::fiter it = m->firstFace(); it != m->lastFace(); ++it) {
-    Subdivide(*it, splitIntoQuads, splitIntoHexas, faceVertices);
-    // if(splitIntoQuads) recombineIntoQuads(*it, true, true);
-  }
+  for(GModel::fiter it = m->firstFace(); it != m->lastFace(); ++it)
+    Subdivide(*it, splitIntoQuads, splitIntoHexas, faceVertices, linear);
   for(GModel::riter it = m->firstRegion(); it != m->lastRegion(); ++it)
     Subdivide(*it, splitIntoHexas, faceVertices);
 
@@ -503,10 +497,10 @@ void BarycentricRefineMesh(GModel *m)
   if(m->getNumRegions() == 0) {
     for(GModel::fiter it = m->firstFace(); it != m->lastFace(); ++it) {
       GFace *gf = *it;
-      unsigned int numt = gf->triangles.size();
+      std::size_t numt = gf->triangles.size();
       if(!numt) continue;
       std::vector<MTriangle *> triangles2(3 * numt);
-      for(unsigned int i = 0; i < numt; i++) {
+      for(std::size_t i = 0; i < numt; i++) {
         MTriangle *t = gf->triangles[i];
         SPoint3 bary = t->barycenter();
         // FIXME: create an MFaceVertex (with correct parametric coordinates)?
@@ -526,10 +520,10 @@ void BarycentricRefineMesh(GModel *m)
   else {
     for(GModel::riter it = m->firstRegion(); it != m->lastRegion(); ++it) {
       GRegion *gr = *it;
-      unsigned int numt = gr->tetrahedra.size();
+      std::size_t numt = gr->tetrahedra.size();
       if(!numt) continue;
       std::vector<MTetrahedron *> tetrahedra2(4 * numt);
-      for(unsigned int i = 0; i < numt; i++) {
+      for(std::size_t i = 0; i < numt; i++) {
         MTetrahedron *t = gr->tetrahedra[i];
         SPoint3 bary = t->barycenter();
         // FIXME: create an MFaceVertex (with correct parametric coordinates)?
@@ -556,7 +550,7 @@ void BarycentricRefineMesh(GModel *m)
   Msg::StatusBar(true, "Done barycentrically refining mesh (%g s)", t2 - t1);
 }
 
-///------ Tristan Carrier Baudouin's Contribution on Full Hex Meshing
+// Tristan Carrier Baudouin's contribution on Full Hex Meshing
 
 static double schneiders_x(int i)
 {
