@@ -504,14 +504,35 @@ double ComputeVonMises(double *V)
                      v23 * v23 + v31 * v31 + v32 * v32 + v33 * v33));
 }
 
-double ComputeScalarRep(int numComp, double *val)
+double ComputeScalarRep(int numComp, double *val, int tensorRep)
 {
   if(numComp == 1)
     return val[0];
   else if(numComp == 3)
     return sqrt(val[0] * val[0] + val[1] * val[1] + val[2] * val[2]);
-  else if(numComp == 9)
-    return ComputeVonMises(val);
+  else if(numComp == 9){
+    if(tensorRep == 0){ // Von-Mises
+      return ComputeVonMises(val);
+    }
+    else{
+      fullMatrix<double> tensor(3, 3);
+      fullVector<double> S(3), imS(3);
+      fullMatrix<double> V(3, 3);
+      fullMatrix<double> rightV(3, 3);
+      for(int j = 0; j < 3; j++) {
+        tensor(j, 0) = val[0 + j * 3];
+        tensor(j, 1) = val[1 + j * 3];
+        tensor(j, 2) = val[2 + j * 3];
+      }
+      tensor.eig(S, imS, V, rightV, true);
+      if(tensorRep == 1){ // max eigenvalue
+        return S(2);
+      }
+      else{ // min eigenvalue
+        return S(0);
+      }
+    }
+  }
   return 0.;
 }
 
@@ -821,7 +842,7 @@ void signedDistancesPointsTriangle(std::vector<double> &distances,
   closePts.clear();
   closePts.resize(pts_size);
 
-  for(unsigned int i = 0; i < pts_size; ++i) distances[i] = 1.e22;
+  for(std::size_t i = 0; i < pts_size; ++i) distances[i] = 1.e22;
 
   SVector3 t1 = p2 - p1;
   SVector3 t2 = p3 - p1;
@@ -838,7 +859,7 @@ void signedDistancesPointsTriangle(std::vector<double> &distances,
   double det = inv3x3(mat, inv);
   if(det == 0.0) return;
 
-  for(unsigned int i = 0; i < pts.size(); i++) {
+  for(std::size_t i = 0; i < pts.size(); i++) {
     double d;
     SPoint3 closePt;
     const SPoint3 &p = pts[i];
@@ -919,7 +940,7 @@ void signedDistancesPointsLine(std::vector<double> &distances,
   distances.resize(pts.size());
   closePts.clear();
   closePts.resize(pts.size());
-  for(unsigned int i = 0; i < pts.size(); i++) {
+  for(std::size_t i = 0; i < pts.size(); i++) {
     double d;
     SPoint3 closePt;
     const SPoint3 &p = pts[i];
@@ -1119,7 +1140,7 @@ void signedDistancesPointsEllipsePoint(std::vector<double> &distances,
   closePts.clear();
   closePts.resize(pts.size());
   double d;
-  for(unsigned int i = 0; i < pts.size(); i++) {
+  for(std::size_t i = 0; i < pts.size(); i++) {
     SPoint3 closePt;
     const SPoint3 &p = pts[i];
     signedDistancePointLine(p1, p2, p, d, closePt);
@@ -1152,7 +1173,7 @@ void signedDistancesPointsEllipseLine(
   closePts.clear();
   closePts.resize(pts.size());
   double d;
-  for(unsigned int i = 0; i < pts.size(); i++) {
+  for(std::size_t i = 0; i < pts.size(); i++) {
     SPoint3 closePt;
     const SPoint3 &p = pts[i];
     signedDistancePointLine(p1, p2, p, d, closePt);
@@ -1518,7 +1539,7 @@ void projectPointsToPlane(const std::vector<SPoint3> &pts,
                           const mean_plane &meanPlane)
 {
   ptsProj.resize(pts.size());
-  for(unsigned int i = 0; i < pts.size(); i++) {
+  for(std::size_t i = 0; i < pts.size(); i++) {
     projectPointToPlane(pts[i], ptsProj[i], meanPlane);
   }
 }
@@ -1533,7 +1554,7 @@ void transformPointsIntoOrthoBasis(const std::vector<SPoint3> &ptsProj,
   SVector3 tangent, binormal;
   buildOrthoBasis(normal, tangent, binormal);
 
-  for(unsigned int i = 0; i < ptsProj.size(); i++) {
+  for(std::size_t i = 0; i < ptsProj.size(); i++) {
     SVector3 pp(ptsProj[i][0] - ptCG[0], ptsProj[i][1] - ptCG[1],
                 ptsProj[i][2] - ptCG[2]);
     pointsUV[i][0] = dot(pp, tangent);
