@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _ELASTICITY_SOLVER_H_
-#define _ELASTICITY_SOLVER_H_
+#ifndef ELASTICITY_SOLVER_H
+#define ELASTICITY_SOLVER_H
 
 #include <map>
 #include <string>
@@ -30,7 +30,7 @@ struct LagrangeMultiplierField {
 struct elasticField {
   int _tag; // tag for the dofManager
   groupOfElements *g; // support for this field
-  double _E, _nu; // specific elastic datas (should be somewhere else)
+  double _e, _nu; // specific elastic datas (should be somewhere else)
   elasticField() : _tag(0), g(0) {}
 };
 
@@ -85,7 +85,7 @@ public:
   virtual ~elasticitySolver()
   {
     if(LagSpace) delete LagSpace;
-    for(unsigned int i = 0; i < LagrangeMultiplierSpaces.size(); i++)
+    for(std::size_t i = 0; i < LagrangeMultiplierSpaces.size(); i++)
       if(LagrangeMultiplierSpaces[i]) delete LagrangeMultiplierSpaces[i];
     LagrangeMultiplierSpaces.clear();
     if(pAssembler) delete pAssembler;
@@ -96,7 +96,7 @@ public:
   virtual void setMesh(const std::string &meshFileName, int dim = 0);
   void cutMesh(gLevelset *ls);
   void setElasticDomain(int phys, double E, double nu);
-  void setLagrangeMultipliers(int phys, double tau, SVector3 d, int tag,
+  void setLagrangeMultipliers(int phys, double tau, const SVector3 &d, int tag,
                               simpleFunction<double> *f);
   void changeLMTau(int tag, double tau);
   void setEdgeDisp(int edge, int comp, simpleFunction<double> *f);
@@ -108,7 +108,7 @@ public:
   virtual PView *buildDisplacementView(const std::string postFileName);
   virtual PView *buildStrainView(const std::string postFileName);
   virtual PView *buildStressesView(const std::string postFileName);
-  virtual PView *buildLagrangeMultiplierView(const std::string posFileName,
+  virtual PView *buildLagrangeMultiplierView(const std::string &posFileName,
                                              int tag = -1);
   virtual PView *buildElasticEnergyView(const std::string postFileName);
   virtual PView *buildVonMisesView(const std::string postFileName);
