@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _MESH_GFACE_QUADRILATERALIZE_
-#define _MESH_GFACE_QUADRILATERALIZE_
+#ifndef MESH_GFACE_QUADRILATERALIZE
+#define MESH_GFACE_QUADRILATERALIZE
 
 class GFace;
 int gmshQMorph(GFace *gf);
