@@ -1,15 +1,15 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _OS_H_
-#define _OS_H_
+#ifndef MY_OS_H
+#define MY_OS_H
 
 #include <string>
 
 const char *GetEnvironmentVar(const char *var);
-double GetTimeInSeconds();
+double TimeOfDay();
 void SleepInSeconds(double s);
 void CheckResources();
 double Cpu();
